PlainTextItem : Plain positional text, used in collections of brief labels and descriptors.
Fields
position: i32The rank or index of this text item within the collection. Different items cannot occupy the same position within a single collection.
value: StringThe actual plain text.
Implementations
sourceimpl PlainTextItem
impl PlainTextItem
sourcepub fn new(position: i32, value: String) -> PlainTextItem
pub fn new(position: i32, value: String) -> PlainTextItem
Plain positional text, used in collections of brief labels and descriptors.